@@ -10,7 +10,7 @@
 /*									     */
 /*									     */
 /*****************************************************************************/
-#if defined(useXaw) || defined(useMotif)
+#if defined(useXaw) || defined(useXm)
 #include "X-pat.h"
 
 #include <X11/IntrinsicP.h>
@@ -23,6 +23,7 @@ static XtResource resources[] = {
     {XtNmessageFile,XtCMessageFile,XtRString,sizeof(String),  offset(messagefile), XtRString, NULL},
     {XtNkeyboardFile,XtCKeyboardFile,XtRString,sizeof(String),offset(keyboardfile),XtRString, NULL},
     {XtNxpmdir,  XtCXpmdir,  XtRString,    sizeof(String),    offset(xpmdir),   XtRString,    NULL},
+    {XtNxpmcls,  XtCXpmcls,  XtRInt,       sizeof(int),       offset(xpmcls),   XtRImmediate, (XtPointer)DEFAULT_CLOSENESS},
 #ifdef LOADCARDS
     {XtNcardset, XtCCardset, XtRString,    sizeof(String),    offset(cardset),  XtRString,    NULL},
 #endif
@@ -156,14 +157,16 @@ static Widget toplev = NULL;
 
 static void Resize(Widget gw) {
     TableauWidget w = (TableauWidget) gw;
-    /* printf("Parent wants me to have size %d,%d\n",
-	   w->core.width, w->core.height); */
+#ifdef LABER
+    printf("Resize(): Parent wants me to have size %d,%d\n",
+	   w->core.width, w->core.height);
+#endif
     resize_event(w->core.width, w->core.height);
     /* (*pileWidgetClass->core_class.superclass->core_class.resize)(gw); */
 }
 
 void AskWidgetForResize(XSize_t x, XSize_t y) {
-#ifdef useMotif
+#ifdef useXm
     Arg Args[2];
     XtSetArg(Args[0], XtNwidth, x);
     XtSetArg(Args[1], XtNheight, y);
@@ -219,14 +222,18 @@ static void Initialize(Widget request, Widget xnew, ArgList args, Cardinal *n) {
 	exit(EXIT_FAILURE);
     }
 
-    {  const char *s; langdir = (s = getenv("LANG")) ? s : ""; }
     read_message_file(p->messagefile ? p->messagefile : "messages");
-    read_keyboard_file(p->keyboardfile ? p->keyboardfile : "Keys");
+    read_keyboard_file(p->keyboardfile ? p->keyboardfile : "keys");
 
     /* assign global data for old Xlib program */
     dpy    = XtDisplay(new);
     screen = DefaultScreen(dpy);
     graphic.is_color = (DisplayCells(dpy, screen) > 2);
+#if defined(GFX2) && defined(LOADCARDS)
+    if (!graphic.is_color && !p->cardset)
+	p->cardset = "french";	/* use B&W cardset, xpm requires too much colours */
+#endif
+
     /* validity checks */
     CHECK(p->decks,	-1, 9);
     CHECK(p->slots,	-1, 32);
@@ -258,12 +265,14 @@ static void Initialize(Widget request, Widget xnew, ArgList args, Cardinal *n) {
 #else
 	       NULL,
 #endif
-	       -1, -1, p->redcolor, p->cbcolor, 1, p->xpmdir);
+	       -1, -1, p->redcolor, p->cbcolor, 1, p->xpmdir, p->xpmcls);
+
+    geo.aw = geo.ah = CARD_WIDTH / 16;
     if (p->arrowwidth <= 30 && p->arrowheight <= 30) {
-	graphic.aw = p->arrowwidth;
-	graphic.ah = p->arrowheight;
+	geo.aw = p->arrowwidth;
+	geo.ah = p->arrowheight;
     }
-    if (graphic.aw > 0 && graphic.ah > 0)
+    if (geo.aw > 0 && geo.ah > 0)
 	hintgc = simpleGC(BlackPixel(dpy, screen), p->arrowcolor);
 
     graphic.xgap = p->xgap;
@@ -273,9 +282,9 @@ static void Initialize(Widget request, Widget xnew, ArgList args, Cardinal *n) {
     printf("size = (%d,%d) and (%d,%d) in Initialize(), computing minwindow:\n",
 	   graphic.width, graphic.height, new->core.width, new->core.height);
 #endif
-    generic_minwindow((XSize_t *)&graphic.width, (XSize_t *)&graphic.height);
-    graphic.min_width = graphic.width;
-    graphic.min_height = graphic.height;
+    generic_minwindow();
+    graphic.width = geo.min_width;
+    graphic.height = geo.min_height;
 #ifdef LABER
     printf("result is (%d,%d)\n", graphic.width, graphic.height);
 #endif
