@@ -70,13 +70,8 @@ Move SlotShuffle(int fwd) {
     Cardindex start = INDEX_OF_FIRST_CARD(FIRST_SLOT);
 
     sprand(game.seed);
-    for (i = 0; i < num; ++i) {
-	int j;
-	j = myrand(num);
-	if (j < i)	/* some correction */
-	    j = i;
-	tab[i] = j;
-    }
+    for (i = 0; i < num; ++i)
+	tab[i] = myrand(num - i) + i;
     if (fwd) {
 	for (i = 0; i < num; ++i)
 	    if (tab[i] != i) {
@@ -667,7 +662,8 @@ Move give_new_cards(void) {
 extern struct rules Spider_rules, Gypsy_rules, Klondike_rules, modSpider_rules;
 extern struct rules Seahaven_rules, FreeCell_rules, IdiotsDelight_rules,
     MonteCarlo_rules, MidnightOil_rules, Calculation_rules, Michaels_rules,
-    Canfield_rules, modCanfield_rules, Royal_rules, Bakers_rules;
+    Canfield_rules, modCanfield_rules, Royal_rules, Bakers_rules, Oonsoo_rules,
+    BlueMoon_rules;
 
 struct game game;
 struct rules rules;
@@ -687,6 +683,8 @@ struct rules *rulepool[] = {
     &Canfield_rules,
     &Royal_rules,
     &Bakers_rules,
+    &Oonsoo_rules,
+    &BlueMoon_rules,
     NULL
 };
 
